==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/heo420.h <==
/****************************************************************************

  module      : heo420.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: communication ...
  description : description ...


  last changed: 1999-11-02  13:29
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO420_H
#define HEO420_H


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo003.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/


externC tsp00_Uint1 
eo420NewSwapType ();

externC teo00_Longuint
eo420ServiceTypeToMessClass ( teo00_Longuint ulServiceType ) ;

externC void
eo420InitConPktParamRec     ( teo003_ConPktParamRecord *pConPktParamRec );
  
externC void
eo420UnpackRteHeader        ( teo00_Longuint                ulSwapType,
                              teo003_RteHeaderRecord       *pRTEHeader,
                              tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

externC teo00_Longuint
eo420GetDBRootFromConPkt    ( teo003_RteConnectPacketRec *pConnectPacket,
                              char                       *szDBRoot );
externC teo00_Longuint
eo420GetServerPgmFromConPkt ( teo003_RteConnectPacketRec *pConnectPacket,
                              char                       *szServerPgm ) ;

externC teo00_Longuint
eo420SendRteHeader     ( void                         *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003       SendFunc,
                         teo00_Longuint                ulSenderRef,
                         teo00_Longuint                ulReceiverRef,
                         teo00_Longuint                ulMessClass,
                         teo00_Longuint                ulCommState,
                         tsp00_ErrTextc  VAR_ARRAY_REF pErrText ) ;

externC teo00_Longuint
eo420ReceiveRteHeader  ( void                          *RecvHandle,
                         RECV_PKT_FUNC_PTR_EO003        RecvFunc,
                         teo00_Longuint                 ulSwapType,
                         teo00_Longuint                *pulSenderRef,
                         teo00_Longuint                *pulReceiverRef,
                         teo00_Longuint                *pulMessClass,
                         tsp00_ErrTextc  VAR_ARRAY_REF  pErrText );

externC tsp00_Longuint 
eo420ReceiveConnectPacket( void                         *RecvHandle,
                           RECV_PKT_FUNC_PTR_EO003       RecvFunc,
                           teo003_ConPktParamRecord     *pConPktParamRec,
                           tsp00_ErrTextc VAR_ARRAY_REF  ErrText );

externC teo00_Longuint
eo420SendConnectPacket ( void                          *SendHandle, 
                         SEND_PKT_FUNC_PTR_EO003        SendFunc,
                         teo003_ConPktParamRecord      *pConPktParamRec,
                         tsp00_ErrTextc  VAR_ARRAY_REF  pErrText );
externC teo00_Longuint
eo420SendCommPacket    ( void                         *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003       SendFunc,
                         teo00_Longuint                ulMaxSegmentSize,
                         teo003_CommPacketRecord      *pCommPacket,
                         teo00_Longuint                ulDataLen,
                         teo00_Longuint                ulSenderRef,
                         teo00_Longuint                ulReceiverRef,
                         teo00_Longuint                ulMessClass,
                         teo00_Longuint                ulCommState,
                         tsp00_ErrTextc  VAR_ARRAY_REF pErrText ) ;

externC teo00_Longuint
eo420SendReleasePacket ( void                      *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003    SendFunc,
                         teo00_Longuint             ulSenderRef,
                         teo00_Longuint             ulReceiverRef,
                         teo00_Longuint             ulMessClass,
                         teo00_Longuint             ulCommState) ;

externC teo00_Longuint
eo420ReceiveCommPacket ( void                         *RecvHandle,
                         RECV_PKT_FUNC_PTR_EO003       RecvFunc,
                         teo00_Longuint                ulSwapType,
                         teo003_CommPacketRecord      *pCommPacket,
                         teo00_Longuint                ulMaxDataLen,
                         teo00_Longuint               *pulDataLen,
                         teo00_Longuint               *pulSenderRef,
                         teo00_Longuint               *pulReceiverRef,
                         teo00_Longuint               *pulMessClass,
                         tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

externC tsp00_Longuint
eo420SetSocketBufferSize ( int                           SocketHandle,
                           tsp00_Longuint                ulMinSendLen,
                           tsp00_Longuint               *ulMaxSendLen,
                           tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

externC tsp00_Longuint
eo420SetNiSocketBufferSize ( void                         *NiHandle,
                             tsp00_Longuint                ulMinSendLen,
                             tsp00_Longuint               *ulMaxSendLen,
                             tsp00_ErrTextc VAR_ARRAY_REF  pErrText );
#endif  /* HEO420_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/heo420.h <==
/****************************************************************************

  module      : heo420.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: communication ...
  description : description ...


  last changed: 1999-11-02  13:29
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO420_H
#define HEO420_H


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo003.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/


externC tsp00_Uint1 
eo420NewSwapType ();

externC tsp00_Uint    
eo420ServiceTypeToMessClass ( tsp00_Uint     ulServiceType ) ;

externC void
eo420InitConPktParamRec     ( teo003_ConPktParamRecord *pConPktParamRec );
  
externC void
eo420UnpackRteHeader        ( tsp00_Uint                    ulSwapType,
                              teo003_RteHeaderRecord       *pRTEHeader,
                              tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

externC tsp00_Uint    
eo420GetDBRootFromConPkt    ( teo003_RteConnectPacketRec *pConnectPacket,
                              char                       *szDBRoot );
externC tsp00_Uint    
eo420GetServerPgmFromConPkt ( teo003_RteConnectPacketRec *pConnectPacket,
                              char                       *szServerPgm ) ;

externC tsp00_Uint    
eo420SendRteHeader     ( void                         *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003       SendFunc,
                         tsp00_Uint                    ulSenderRef,
                         tsp00_Uint                    ulReceiverRef,
                         tsp00_Uint                    ulMessClass,
                         tsp00_Uint                    ulCommState,
                         tsp00_ErrTextc  VAR_ARRAY_REF pErrText ) ;

externC tsp00_Uint    
eo420ReceiveRteHeader  ( void                          *RecvHandle,
                         RECV_PKT_FUNC_PTR_EO003        RecvFunc,
                         tsp00_Uint                     ulSwapType,
                         tsp00_Uint                    *pulSenderRef,
                         tsp00_Uint                    *pulReceiverRef,
                         tsp00_Uint                    *pulMessClass,
                         tsp00_ErrTextc  VAR_ARRAY_REF  pErrText );

externC tsp00_Uint     
eo420ReceiveConnectPacket( void                         *RecvHandle,
                           RECV_PKT_FUNC_PTR_EO003       RecvFunc,
                           teo003_ConPktParamRecord     *pConPktParamRec,
                           tsp00_ErrTextc VAR_ARRAY_REF  ErrText );

externC tsp00_Uint    
eo420SendConnectPacket ( void                          *SendHandle, 
                         SEND_PKT_FUNC_PTR_EO003        SendFunc,
                         teo003_ConPktParamRecord      *pConPktParamRec,
                         tsp00_ErrTextc  VAR_ARRAY_REF  pErrText );
externC tsp00_Uint    
eo420SendCommPacket    ( void                         *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003       SendFunc,
                         tsp00_Uint                    ulMaxSegmentSize,
                         teo003_CommPacketRecord      *pCommPacket,
                         tsp00_Uint                    ulDataLen,
                         tsp00_Uint                    ulSenderRef,
                         tsp00_Uint                    ulReceiverRef,
                         tsp00_Uint                    ulMessClass,
                         tsp00_Uint                    ulCommState,
                         tsp00_ErrTextc  VAR_ARRAY_REF pErrText ) ;

externC tsp00_Uint    
eo420SendReleasePacket ( void                      *SendHandle,
                         SEND_PKT_FUNC_PTR_EO003    SendFunc,
                         tsp00_Uint                 ulSenderRef,
                         tsp00_Uint                 ulReceiverRef,
                         tsp00_Uint                 ulMessClass,
                         tsp00_Uint                 ulCommState) ;

externC tsp00_Uint    
eo420ReceiveCommPacket ( void                         *RecvHandle,
                         RECV_PKT_FUNC_PTR_EO003       RecvFunc,
                         tsp00_Uint                    ulSwapType,
                         teo003_CommPacketRecord      *pCommPacket,
                         tsp00_Uint                    ulMaxDataLen,
                         tsp00_Uint                   *pulDataLen,
                         tsp00_Uint                   *pulSenderRef,
                         tsp00_Uint                   *pulReceiverRef,
                         tsp00_Uint                   *pulMessClass,
                         tsp00_ErrTextc VAR_ARRAY_REF  pErrText );

#if defined (RTE_USE_SOCK)
externC tsp00_Uint    
eo420SetSocketBufferSize ( teo00_Socket                  SocketHandle,
                           tsp00_Uint                    ulMinSendLen,
                           tsp00_Uint                   *ulMaxSendLen,
                           tsp00_ErrTextc VAR_ARRAY_REF  pErrText );
#endif

externC tsp00_Uint    
eo420SetNiSocketBufferSize ( void                         *NiHandle,
                             tsp00_Uint                    ulMinSendLen,
                             tsp00_Uint                   *ulMaxSendLen,
                             tsp00_ErrTextc VAR_ARRAY_REF  pErrText );
#endif  /* HEO420_H */
